translate.convert.dtd2po.dtd2po

Package translate :: Package convert :: Module dtd2po :: Class dtd2po |
[hide private]
[frames] | no frames]

# Class dtd2po

source code

Instance Methods | [hide private]
__init__(self, blankmsgstr=False, duplicatestyle="msgctxt") | source code
convertcomments(self, thedtd, thepo) | source code
convertstrings(self, thedtd, thepo) | source code
convertunit(self, thedtd) converts a dtd unit to a po unit, returns None if empty or not for translation | source code
convertmixedunit(self, labeldtd, accesskeydtd) | source code
findmixedentities(self, thedtdfile) creates self.mixedentities from the dtd file... | source code
convertdtdunit(self, thedtdfile, thedtd, mixbucket="dtd") converts a dtd unit from thedtdfile to a po unit, handling mixed entities along the way... | source code
convertstore(self, thedtdfile) | source code
mergestore(self, origdtdfile, translateddtdfile) | source code